<?php

// Adds pretty filesizes
function pretty_filesize($file) {
    $size = filesize($file);
    if ($size < 1024) {
        $size = $size . " Bytes";
    } elseif (($size < 1048576) && ($size > 1023)) {
        $size = round($size / 1024, 1) . " KB";
    } elseif (($size < 1073741824) && ($size > 1048575)) {
        $size = round($size / 1048576, 1) . " MB";
    } else {
        $size = round($size / 1073741824, 1) . " GB";
    }
    return $size;
}

function cmp($a, $b)
{
    if ($a['isdir'] == $b['isdir'])
        return strcmp($a['filename'], $b['filename']);
    return $a['isdir'] && !$b['isdir'] ? -1 : 1;
}

date_default_timezone_set("Europe/Rome");

// Checks to see if veiwing hidden files is enabled
/*
  if ($_SERVER['QUERY_STRING'] == "hidden") {
    $hide = "";
    $ahref = "./";
    $atext = "Hide";
  } else {

    $hide = ".";
    $ahref = "./?hidden";
    $atext = "Show";
  }
 */

$hide = ".";

if (!isset($_SERVER['QUERY_STRING']) || $_SERVER['QUERY_STRING'] == "" || substr($_SERVER['QUERY_STRING'],0,2) == ".." || strstr($_SERVER['QUERY_STRING'], "..")) {
    $currdir = ".";
} else {
    $currdir = urldecode($_SERVER['QUERY_STRING']);
}

if ($currdir == ".") 
    $label = "mp3.duas.org";
else {
    $path = explode('/', $currdir);
    $label = $path[count($path)-1]; 
}

?>

<!doctype html>
<html>
    <head>
        <meta charset="UTF-8">
		<meta name="viewport" content="width=device-width, initial-scale=1">
        <link rel="shortcut icon" href="./.favicon.ico">
        <title><?= $label ?></title>

      <link rel="stylesheet" href="./.style.css">
        <script src="./.sorttable.js"></script>
		<link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css" integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
		<link rel="stylesheet" href="https://www.duas.org/css/standard-style-01.css?h=0010"> 
    </head>

    <body>
        <div id="container">
			<P align="center"><img src="https://www.duas.org/images/duas_logo.png" width="140" height="35" alt="Duas.org"></a></p>

            <h1><?= $label ?></h1>

            <table class="sortable">
                <thead>
                    <tr>
                        <th>File Name</th>
                        <th>Type</th>
                    </tr>
                </thead>
                <tbody>
<?php

// Opens directory
$myDirectory = opendir($currdir) or die();

// Gets each entry
while (false !== ($entryName = readdir($myDirectory))) {
    $dirArray[] = array('filename' => $entryName, 'isdir' => is_dir($currdir.'/'.$entryName));
}

// Closes directory
closedir($myDirectory);

// Counts elements in array
$indexCount = count($dirArray);

// Sorts files
usort($dirArray, "cmp");

// Loops through the array of files
for ($index = 0; $index < $indexCount; $index++) {

    // Decides if hidden files should be displayed, based on query above.
    if (substr($dirArray[$index]['filename'], 0, 1) != $hide || ($currdir != '.' && $dirArray[$index]['filename'] == "..")) {

        // Resets Variables
        $favicon = "";
        $class = "file";

        // Gets File Names
        $name = $dirArray[$index]['filename'];
        $namehref = ($currdir == "." ? "" : $currdir . '/') . $dirArray[$index]['filename'];
        $fullname = $currdir . '/' . $dirArray[$index]['filename'];

        // Gets Date Modified
        $modtime = date("M j Y g:i A", filemtime($fullname));
        $timekey = date("YmdHis", filemtime($fullname));


        // Separates directories, and performs operations on those directories
        if (is_dir($fullname)) {
            $extn = "&lt;Directory&gt;";
            $size = "&lt;Directory&gt;";
            $sizekey = "0";
            $class = "dir";

            // Gets favicon.ico, and displays it, only if it exists.
            if (file_exists("$namehref/favicon.ico")) {
                $favicon = " style='background-image:url($namehref/favicon.ico);'";
                $extn = "&lt;Website&gt;";
            }

            // Cleans up . and .. directories
            if ($name == ".") {
                $name = ". (Current Directory)";
                $extn = "&lt;System Dir&gt;";
                $favicon = " style='background-image:url($namehref/.favicon.ico);'";
            }
            if ($name == "..") {
                $name = ".. (Back)";
                $extn = "&lt;System Dir&gt;";
            }
            if ($currdir == "." && $dirArray[$index]['filename'] == "..")
                $namehref = "";
            elseif ($dirArray[$index]['filename'] == "..") {
                $dirs = explode('/', $currdir);
                unset($dirs[count($dirs) - 1]);
                $prevdir = implode('/', $dirs);
                $namehref = '?' . $prevdir;
            }
            else
                $namehref = '?' . $namehref;
        }

        // File-only operations
        else {
            // Gets file extension
            $extn = pathinfo($dirArray[$index]['filename'], PATHINFO_EXTENSION);

            // Prettifies file type
            switch ($extn) {
                case "png": $extn = "PNG Image";
                    break;
                case "jpg": $extn = "JPEG Image";
                    break;
                case "jpeg": $extn = "JPEG Image";
                    break;
                case "svg": $extn = "SVG Image";
                    break;
                case "gif": $extn = "GIF Image";
                    break;
                case "ico": $extn = "Windows Icon";
                    break;

                case "txt": $extn = "Text File";
                    break;
                case "log": $extn = "Log File";
                    break;
                case "htm": $extn = "HTML File";
                    break;
                case "html": $extn = "HTML File";
                    break;
                case "xhtml": $extn = "HTML File";
                    break;
                case "shtml": $extn = "HTML File";
                    break;
                case "php": $extn = "PHP Script";
                    break;
                case "js": $extn = "Javascript File";
                    break;
                case "css": $extn = "Stylesheet";
                    break;

                case "pdf": $extn = "PDF Document";
                    break;
                case "xls": $extn = "Spreadsheet";
                    break;
                case "xlsx": $extn = "Spreadsheet";
                    break;
                case "doc": $extn = "Microsoft Word Document";
                    break;
                case "docx": $extn = "Microsoft Word Document";
                    break;

                case "zip": $extn = "ZIP Archive";
                    break;
                case "htaccess": $extn = "Apache Config File";
                    break;
                case "exe": $extn = "Windows Executable";
                    break;

                default: if ($extn != "") {
                        $extn = strtoupper($extn) . " File";
                    } else {
                        $extn = "Sconosciuto";
                    } break;
            }

            // Gets and cleans up file size
            $size = pretty_filesize($fullname);
            $sizekey = filesize($fullname);
        }

        // Output 
        echo("
        <tr class='$class'>
            <td sorttable_customkey='$index'><a href='$namehref'$favicon class='name'>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;$name</a>
			<td sorttable_customkey='$sizekey'><a href='./$namehref'>$size</a></td>

        </tr>");
    }
}
?>

                </tbody>
            </table>

        </div>
		
		<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.4.1/jquery.min.js"></script>
	<script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.7/umd/popper.min.js" integrity="sha384-UO2eT0CpHqdSJQ6hJty5KVphtPhzWj9WO1clHTMGa3JDZwrnQq4sF86dIHNDz0W1" crossorigin="anonymous"></script>
	<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js" integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM" crossorigin="anonymous"></script>
	<script src="https://code.jquery.com/jquery-1.12.4.min.js" integrity="sha384-nvAa0+6Qg9clwYCGGPpDQLVpLNn0fRaROjHqs13t4Ggj3Ez50XnGQqc/r8MhnRDZ" crossorigin="anonymous"></script>
    </body>
</html>